#!/usr/bin/env python
# setup.py generated by flit for tools that don't yet use PEP 517

from distutils.core import setup


setup(name='pyeucountrycodes',
      version='1.2.0',
      description='All ISO 3166 country codes for EU countries.',
      author='Jürgen Gmach',
      author_email='juergen.gmach@googlemail.com',
      url='https://github.com/jugmac00/pyeucountrycodes',
      py_modules=['eu_country_codes'],
      python_requires='>=3.6',
     )
